@@ -22,6 +22,7 @@
 #include "progressBox.h"
 
 #include "scan.h"
+#include "part.h"
 
 #include <KColorScheme>
 #include <KIO/Job>
@@ -36,9 +37,9 @@
 #include <math.h>
 
 
-ProgressBox::ProgressBox(QWidget *parent, QObject *part, Filelight::ScanManager *m)
+ProgressBox::ProgressBox(QWidget *parent, Filelight::Part *part, Filelight::ScanManager *scanManager)
         : QWidget(parent)
-        , m_manager(m)
+        , m_manager(scanManager)
 {
     hide();
 
@@ -51,10 +52,10 @@ ProgressBox::ProgressBox(QWidget *parent, QObject *part, Filelight::ScanManager
     setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     setMinimumSize(200, 200);
 
-    connect(&m_timer, SIGNAL(timeout()), SLOT(report()));
-    connect(part, SIGNAL(started(KIO::Job*)), SLOT(start()));
-    connect(part, SIGNAL(completed()), SLOT(stop()));
-    connect(part, SIGNAL(canceled(QString)), SLOT(halt()));
+    connect(&m_timer, &QTimer::timeout, this, &ProgressBox::report);
+    connect(part, &Filelight::Part::started, this, &ProgressBox::start);
+    connect(part, static_cast<void (Filelight::Part::*)()>(&Filelight::Part::completed), this, &ProgressBox::stop);
+    connect(part, &Filelight::Part::canceled, this, &ProgressBox::halt);
 }
 
 void
@@ -97,7 +98,6 @@ ProgressBox::setText(int files)
 #define PIECES_NUM 4
 static const float angleFactor[] = { -0.75, 0.5, 1.0, -0.3 };
 static const int length[] = { 30, 40, 50, 60 };
-static const int angleOffset[] = { 5760, 0, 0, -5760 };
 static const int aLength[] = { 300, 2000, 200, 2000 };
 
 void ProgressBox::paintEvent(QPaintEvent*)
@@ -123,9 +123,10 @@ void ProgressBox::paintEvent(QPaintEvent*)
     paint.setBrush(view.background(KColorScheme::ActiveBackground));
     paint.setPen(view.foreground().color());
     paint.translate(0.5, 0.5);
-    paint.drawRoundedRect(95-m_textWidth/2, 85, m_textWidth+10, m_textHeight+10, 5, 5);
+    QRectF textRect(100 - m_textWidth/2 - 5, 100 - m_textHeight - 5, m_textWidth + 10, m_textHeight + 10);
+    paint.drawRoundedRect(textRect, 5, 5);
     paint.translate(-0.5, -0.5);
-    paint.drawText(100 - m_textWidth/2, 100, m_text);
+    paint.drawText(textRect, Qt::AlignCenter, m_text);
 }
 
 
