@@ -38,15 +38,14 @@ public:
     ~RemoteLister();
 
 signals:
-    void branchCompleted(Folder* tree, bool finished);
+    void branchCompleted(Folder* tree);
 
 private slots:
     void completed();
-    void _completed();
     void canceled();
 
 private:
-    class Store *m_root, *m_store;
+    struct Store *m_root, *m_store;
     ScanManager* m_manager;
 };
 }
